==> haskell-bytestring-progress-1.4-142-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-bytestring-progress.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 bytestring-progress
version:              1.4
visibility:           public
id:                   bytestring-progress-1.4-DEl3d5lz31S7grMXynZLmJ
key:                  bytestring-progress-1.4-DEl3d5lz31S7grMXynZLmJ
license:              BSD-3-Clause
maintainer:           Adam Wick <awick@uhsure.com>
author:               Adam Wick <awick@uhsure.com>
homepage:             http://github.com/acw/bytestring-progress
synopsis:             A library for tracking the consumption of a lazy ByteString
description:
    In some cases, it is useful to know how fast a ByteString is being
    consumed. Typically, this could be to report some measure of progress
    to a waiting user, but it could also be to perform some form of testing
    on input / consumption code.

category:             Control
abi:                  401c6d376cbeb65fdcbcdc70a487398c
exposed:              True
exposed-modules:
    Data.ByteString.Lazy.Progress System.ProgressBar.ByteString

import-dirs:          /usr/lib/ghc-9.4.8/site-local/bytestring-progress-1.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/bytestring-progress-1.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/bytestring-progress-1.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-bytestring-progress
hs-libraries:         HSbytestring-progress-1.4-DEl3d5lz31S7grMXynZLmJ
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    terminal-progress-bar-0.4.2-Ift2U2umtvm89CkNo7uwge text-2.0.2
    time-1.12.2

haddock-interfaces:
    /usr/share/doc/haskell-bytestring-progress/html/bytestring-progress.haddock

haddock-html:         /usr/share/doc/haskell-bytestring-progress/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-bytestring-progress-1.4-143-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-bytestring-progress.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 bytestring-progress
version:              1.4
visibility:           public
id:                   bytestring-progress-1.4-ICWBEiNiAXP14jAmE8de6S
key:                  bytestring-progress-1.4-ICWBEiNiAXP14jAmE8de6S
license:              BSD-3-Clause
maintainer:           Adam Wick <awick@uhsure.com>
author:               Adam Wick <awick@uhsure.com>
homepage:             http://github.com/acw/bytestring-progress
synopsis:             A library for tracking the consumption of a lazy ByteString
description:
    In some cases, it is useful to know how fast a ByteString is being
    consumed. Typically, this could be to report some measure of progress
    to a waiting user, but it could also be to perform some form of testing
    on input / consumption code.

category:             Control
abi:                  c9f2ba379a281386b77a686ced56ac4f
exposed:              True
exposed-modules:
    Data.ByteString.Lazy.Progress System.ProgressBar.ByteString

import-dirs:          /usr/lib/ghc-9.4.8/site-local/bytestring-progress-1.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/bytestring-progress-1.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/bytestring-progress-1.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-bytestring-progress
hs-libraries:         HSbytestring-progress-1.4-ICWBEiNiAXP14jAmE8de6S
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    terminal-progress-bar-0.4.2-KJDYMhV8LBjKmndBcA2wzD text-2.0.2
    time-1.12.2

haddock-interfaces:
    /usr/share/doc/haskell-bytestring-progress/html/bytestring-progress.haddock

haddock-html:         /usr/share/doc/haskell-bytestring-progress/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
